@@ -1,7 +1,11 @@
 """Support for AVM FRITZ!SmartHome devices."""
 from __future__ import annotations
 
+from abc import ABC, abstractmethod
+from xml.etree.ElementTree import ParseError
+
 from pyfritzhome import Fritzhome, FritzhomeDevice, LoginError
+from pyfritzhome.devicetypes.fritzhomeentitybase import FritzhomeEntityBase
 
 from homeassistant.components.binary_sensor import DOMAIN as BINARY_SENSOR_DOMAIN
 from homeassistant.config_entries import ConfigEntry
@@ -40,7 +44,16 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         CONF_CONNECTIONS: fritz,
     }
 
-    coordinator = FritzboxDataUpdateCoordinator(hass, entry)
+    try:
+        await hass.async_add_executor_job(fritz.update_templates)
+    except ParseError:
+        LOGGER.debug("Disable smarthome templates")
+        has_templates = False
+    else:
+        LOGGER.debug("Enable smarthome templates")
+        has_templates = True
+
+    coordinator = FritzboxDataUpdateCoordinator(hass, entry, has_templates)
 
     await coordinator.async_config_entry_first_refresh()
 
@@ -93,7 +106,7 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     return unload_ok
 
 
-class FritzBoxEntity(CoordinatorEntity[FritzboxDataUpdateCoordinator]):
+class FritzBoxEntity(CoordinatorEntity[FritzboxDataUpdateCoordinator], ABC):
     """Basis FritzBox entity."""
 
     def __init__(
@@ -108,30 +121,39 @@ class FritzBoxEntity(CoordinatorEntity[FritzboxDataUpdateCoordinator]):
         self.ain = ain
         if entity_description is not None:
             self.entity_description = entity_description
-            self._attr_name = f"{self.device.name} {entity_description.name}"
+            self._attr_name = f"{self.data.name} {entity_description.name}"
             self._attr_unique_id = f"{ain}_{entity_description.key}"
         else:
-            self._attr_name = self.device.name
+            self._attr_name = self.data.name
             self._attr_unique_id = ain
 
+    @property
+    @abstractmethod
+    def data(self) -> FritzhomeEntityBase:
+        """Return data object from coordinator."""
+
+
+class FritzBoxDeviceEntity(FritzBoxEntity):
+    """Reflects FritzhomeDevice and uses its attributes to construct FritzBoxDeviceEntity."""
+
     @property
     def available(self) -> bool:
         """Return if entity is available."""
-        return super().available and self.device.present
+        return super().available and self.data.present
 
     @property
-    def device(self) -> FritzhomeDevice:
-        """Return device object from coordinator."""
-        return self.coordinator.data[self.ain]
+    def data(self) -> FritzhomeDevice:
+        """Return device data object from coordinator."""
+        return self.coordinator.data.devices[self.ain]
 
     @property
     def device_info(self) -> DeviceInfo:
         """Return device specific attributes."""
         return DeviceInfo(
-            name=self.device.name,
+            name=self.data.name,
             identifiers={(DOMAIN, self.ain)},
-            manufacturer=self.device.manufacturer,
-            model=self.device.productname,
-            sw_version=self.device.fw_version,
+            manufacturer=self.data.manufacturer,
+            model=self.data.productname,
+            sw_version=self.data.fw_version,
             configuration_url=self.coordinator.configuration_url,
         )
