@@ -1,9 +1,14 @@
 """Provides device automations for MQTT."""
+from __future__ import annotations
+
 import functools
 
 import voluptuous as vol
 
+from homeassistant.config_entries import ConfigEntry
+from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 from . import device_trigger
 from .config import MQTT_BASE_SCHEMA
@@ -20,14 +25,19 @@ PLATFORM_SCHEMA = cv.PLATFORM_SCHEMA.extend(
 ).extend(MQTT_BASE_SCHEMA.schema)
 
 
-async def async_setup_entry(hass, config_entry):
+async def async_setup_entry(hass: HomeAssistant, config_entry: ConfigEntry) -> None:
     """Set up MQTT device automation dynamically through MQTT discovery."""
 
     setup = functools.partial(_async_setup_automation, hass, config_entry=config_entry)
     await async_setup_entry_helper(hass, "device_automation", setup, PLATFORM_SCHEMA)
 
 
-async def _async_setup_automation(hass, config, config_entry, discovery_data):
+async def _async_setup_automation(
+    hass: HomeAssistant,
+    config: ConfigType,
+    config_entry: ConfigEntry,
+    discovery_data: DiscoveryInfoType,
+) -> None:
     """Set up an MQTT device automation."""
     if config[CONF_AUTOMATION_TYPE] == AUTOMATION_TYPE_TRIGGER:
         await device_trigger.async_setup_trigger(
@@ -35,6 +45,6 @@ async def _async_setup_automation(hass, config, config_entry, discovery_data):
         )
 
 
-async def async_removed_from_device(hass, device_id):
+async def async_removed_from_device(hass: HomeAssistant, device_id: str) -> None:
     """Handle Mqtt removed from a device."""
     await device_trigger.async_removed_from_device(hass, device_id)
