@@ -1,22 +1,28 @@
 """Config flow for Risco integration."""
 from __future__ import annotations
 
+from collections.abc import Mapping
 import logging
+from typing import Any
 
-from pyrisco import CannotConnectError, RiscoCloud, UnauthorizedError
+from pyrisco import CannotConnectError, RiscoCloud, RiscoLocal, UnauthorizedError
 import voluptuous as vol
 
 from homeassistant import config_entries, core
 from homeassistant.const import (
+    CONF_HOST,
     CONF_PASSWORD,
     CONF_PIN,
+    CONF_PORT,
     CONF_SCAN_INTERVAL,
+    CONF_TYPE,
     CONF_USERNAME,
     STATE_ALARM_ARMED_AWAY,
     STATE_ALARM_ARMED_CUSTOM_BYPASS,
     STATE_ALARM_ARMED_HOME,
     STATE_ALARM_ARMED_NIGHT,
 )
+from homeassistant.data_entry_flow import FlowResult
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 
 from .const import (
@@ -27,18 +33,26 @@ from .const import (
     DEFAULT_OPTIONS,
     DOMAIN,
     RISCO_STATES,
+    TYPE_LOCAL,
 )
 
 _LOGGER = logging.getLogger(__name__)
 
 
-DATA_SCHEMA = vol.Schema(
+CLOUD_SCHEMA = vol.Schema(
     {
         vol.Required(CONF_USERNAME): str,
         vol.Required(CONF_PASSWORD): str,
         vol.Required(CONF_PIN): str,
     }
 )
+LOCAL_SCHEMA = vol.Schema(
+    {
+        vol.Required(CONF_HOST): str,
+        vol.Required(CONF_PORT, default=1000): int,
+        vol.Required(CONF_PIN): str,
+    }
+)
 HA_STATES = [
     STATE_ALARM_ARMED_AWAY,
     STATE_ALARM_ARMED_HOME,
@@ -47,10 +61,10 @@ HA_STATES = [
 ]
 
 
-async def validate_input(hass: core.HomeAssistant, data):
-    """Validate the user input allows us to connect.
+async def validate_cloud_input(hass: core.HomeAssistant, data) -> dict[str, str]:
+    """Validate the user input allows us to connect to Risco Cloud.
 
-    Data has the keys from DATA_SCHEMA with values provided by the user.
+    Data has the keys from CLOUD_SCHEMA with values provided by the user.
     """
     risco = RiscoCloud(data[CONF_USERNAME], data[CONF_PASSWORD], data[CONF_PIN])
 
@@ -62,11 +76,29 @@ async def validate_input(hass: core.HomeAssistant, data):
     return {"title": risco.site_name}
 
 
+async def validate_local_input(
+    hass: core.HomeAssistant, data: Mapping[str, str]
+) -> dict[str, str]:
+    """Validate the user input allows us to connect to a local panel.
+
+    Data has the keys from LOCAL_SCHEMA with values provided by the user.
+    """
+    risco = RiscoLocal(data[CONF_HOST], data[CONF_PORT], data[CONF_PIN])
+    await risco.connect()
+    site_id = risco.id
+    await risco.disconnect()
+    return {"title": site_id}
+
+
 class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
     """Handle a config flow for Risco."""
 
     VERSION = 1
 
+    def __init__(self) -> None:
+        """Init the config flow."""
+        self._reauth_entry: config_entries.ConfigEntry | None = None
+
     @staticmethod
     @core.callback
     def async_get_options_flow(
@@ -77,13 +109,21 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
 
     async def async_step_user(self, user_input=None):
         """Handle the initial step."""
+        return self.async_show_menu(
+            step_id="user",
+            menu_options=["cloud", "local"],
+        )
+
+    async def async_step_cloud(self, user_input=None):
+        """Configure a cloud based alarm."""
         errors = {}
         if user_input is not None:
-            await self.async_set_unique_id(user_input[CONF_USERNAME])
-            self._abort_if_unique_id_configured()
+            if not self._reauth_entry:
+                await self.async_set_unique_id(user_input[CONF_USERNAME])
+                self._abort_if_unique_id_configured()
 
             try:
-                info = await validate_input(self.hass, user_input)
+                info = await validate_cloud_input(self.hass, user_input)
             except CannotConnectError:
                 errors["base"] = "cannot_connect"
             except UnauthorizedError:
@@ -92,10 +132,49 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
                 _LOGGER.exception("Unexpected exception")
                 errors["base"] = "unknown"
             else:
-                return self.async_create_entry(title=info["title"], data=user_input)
+                if not self._reauth_entry:
+                    return self.async_create_entry(title=info["title"], data=user_input)
+                self.hass.config_entries.async_update_entry(
+                    self._reauth_entry,
+                    data=user_input,
+                    unique_id=user_input[CONF_USERNAME],
+                )
+                await self.hass.config_entries.async_reload(self._reauth_entry.entry_id)
+                return self.async_abort(reason="reauth_successful")
 
         return self.async_show_form(
-            step_id="user", data_schema=DATA_SCHEMA, errors=errors
+            step_id="cloud", data_schema=CLOUD_SCHEMA, errors=errors
+        )
+
+    async def async_step_reauth(self, entry_data: Mapping[str, Any]) -> FlowResult:
+        """Handle configuration by re-auth."""
+        self._reauth_entry = await self.async_set_unique_id(entry_data[CONF_USERNAME])
+        return await self.async_step_cloud()
+
+    async def async_step_local(self, user_input=None):
+        """Configure a local based alarm."""
+        errors = {}
+        if user_input is not None:
+            try:
+                info = await validate_local_input(self.hass, user_input)
+            except CannotConnectError:
+                _LOGGER.debug("Cannot connect", exc_info=1)
+                errors["base"] = "cannot_connect"
+            except UnauthorizedError:
+                errors["base"] = "invalid_auth"
+            except Exception:  # pylint: disable=broad-except
+                _LOGGER.exception("Unexpected exception")
+                errors["base"] = "unknown"
+            else:
+                await self.async_set_unique_id(info["title"])
+                self._abort_if_unique_id_configured()
+
+                return self.async_create_entry(
+                    title=info["title"], data={**user_input, **{CONF_TYPE: TYPE_LOCAL}}
+                )
+
+        return self.async_show_form(
+            step_id="local", data_schema=LOCAL_SCHEMA, errors=errors
         )
 
 
