@@ -22,7 +22,6 @@ from homeassistant.const import (
     CONF_FRIENDLY_NAME,
     CONF_UNIQUE_ID,
     CONF_VALUE_TEMPLATE,
-    STATE_OFF,
     STATE_ON,
     STATE_UNAVAILABLE,
     STATE_UNKNOWN,
@@ -58,7 +57,6 @@ CONF_SET_OSCILLATING_ACTION = "set_oscillating"
 CONF_SET_DIRECTION_ACTION = "set_direction"
 CONF_SET_PRESET_MODE_ACTION = "set_preset_mode"
 
-_VALID_STATES = [STATE_ON, STATE_OFF]
 _VALID_DIRECTIONS = [DIRECTION_FORWARD, DIRECTION_REVERSE]
 
 FAN_SCHEMA = vol.All(
@@ -66,7 +64,7 @@ FAN_SCHEMA = vol.All(
     vol.Schema(
         {
             vol.Optional(CONF_FRIENDLY_NAME): cv.string,
-            vol.Required(CONF_VALUE_TEMPLATE): cv.template,
+            vol.Optional(CONF_VALUE_TEMPLATE): cv.template,
             vol.Optional(CONF_PERCENTAGE_TEMPLATE): cv.template,
             vol.Optional(CONF_PRESET_MODE_TEMPLATE): cv.template,
             vol.Optional(CONF_OSCILLATING_TEMPLATE): cv.template,
@@ -144,12 +142,11 @@ class TemplateFan(TemplateEntity, FanEntity):
         )
         friendly_name = self._attr_name
 
-        self._template = config[CONF_VALUE_TEMPLATE]
+        self._template = config.get(CONF_VALUE_TEMPLATE)
         self._percentage_template = config.get(CONF_PERCENTAGE_TEMPLATE)
         self._preset_mode_template = config.get(CONF_PRESET_MODE_TEMPLATE)
         self._oscillating_template = config.get(CONF_OSCILLATING_TEMPLATE)
         self._direction_template = config.get(CONF_DIRECTION_TEMPLATE)
-        self._supported_features = 0
 
         self._on_script = Script(hass, config[CONF_ON_ACTION], friendly_name, DOMAIN)
         self._off_script = Script(hass, config[CONF_OFF_ACTION], friendly_name, DOMAIN)
@@ -178,7 +175,7 @@ class TemplateFan(TemplateEntity, FanEntity):
                 hass, set_direction_action, friendly_name, DOMAIN
             )
 
-        self._state = STATE_OFF
+        self._state: bool | None = False
         self._percentage = None
         self._preset_mode = None
         self._oscillating = None
@@ -191,18 +188,13 @@ class TemplateFan(TemplateEntity, FanEntity):
         self._preset_modes = config.get(CONF_PRESET_MODES)
 
         if self._percentage_template:
-            self._supported_features |= FanEntityFeature.SET_SPEED
+            self._attr_supported_features |= FanEntityFeature.SET_SPEED
         if self._preset_mode_template and self._preset_modes:
-            self._supported_features |= FanEntityFeature.PRESET_MODE
+            self._attr_supported_features |= FanEntityFeature.PRESET_MODE
         if self._oscillating_template:
-            self._supported_features |= FanEntityFeature.OSCILLATE
+            self._attr_supported_features |= FanEntityFeature.OSCILLATE
         if self._direction_template:
-            self._supported_features |= FanEntityFeature.DIRECTION
-
-    @property
-    def supported_features(self) -> int:
-        """Flag supported features."""
-        return self._supported_features
+            self._attr_supported_features |= FanEntityFeature.DIRECTION
 
     @property
     def speed_count(self) -> int:
@@ -215,9 +207,9 @@ class TemplateFan(TemplateEntity, FanEntity):
         return self._preset_modes
 
     @property
-    def is_on(self) -> bool:
+    def is_on(self) -> bool | None:
         """Return true if device is on."""
-        return self._state == STATE_ON
+        return self._state
 
     @property
     def preset_mode(self) -> str | None:
@@ -254,23 +246,27 @@ class TemplateFan(TemplateEntity, FanEntity):
             },
             context=self._context,
         )
-        self._state = STATE_ON
 
         if preset_mode is not None:
             await self.async_set_preset_mode(preset_mode)
         elif percentage is not None:
             await self.async_set_percentage(percentage)
 
+        if self._template is None:
+            self._state = True
+            self.async_write_ha_state()
+
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn off the fan."""
         await self.async_run_script(self._off_script, context=self._context)
-        self._state = STATE_OFF
+
+        if self._template is None:
+            self._state = False
+            self.async_write_ha_state()
 
     async def async_set_percentage(self, percentage: int) -> None:
         """Set the percentage speed of the fan."""
-        self._state = STATE_OFF if percentage == 0 else STATE_ON
         self._percentage = percentage
-        self._preset_mode = None
 
         if self._set_percentage_script:
             await self.async_run_script(
@@ -279,6 +275,10 @@ class TemplateFan(TemplateEntity, FanEntity):
                 context=self._context,
             )
 
+        if self._template is None:
+            self._state = percentage != 0
+            self.async_write_ha_state()
+
     async def async_set_preset_mode(self, preset_mode: str) -> None:
         """Set the preset_mode of the fan."""
         if self.preset_modes and preset_mode not in self.preset_modes:
@@ -290,9 +290,7 @@ class TemplateFan(TemplateEntity, FanEntity):
             )
             return
 
-        self._state = STATE_ON
         self._preset_mode = preset_mode
-        self._percentage = None
 
         if self._set_preset_mode_script:
             await self.async_run_script(
@@ -301,6 +299,10 @@ class TemplateFan(TemplateEntity, FanEntity):
                 context=self._context,
             )
 
+        if self._template is None:
+            self._state = True
+            self.async_write_ha_state()
+
     async def async_oscillate(self, oscillating: bool) -> None:
         """Set oscillation of the fan."""
         if self._set_oscillating_script is None:
@@ -340,23 +342,23 @@ class TemplateFan(TemplateEntity, FanEntity):
             self._state = None
             return
 
-        # Validate state
-        if result in _VALID_STATES:
+        if isinstance(result, bool):
             self._state = result
-        elif result in (STATE_UNAVAILABLE, STATE_UNKNOWN):
-            self._state = None
-        else:
-            _LOGGER.error(
-                "Received invalid fan is_on state: %s for entity %s. Expected: %s",
-                result,
-                self.entity_id,
-                ", ".join(_VALID_STATES),
-            )
-            self._state = None
+            return
+
+        if isinstance(result, str):
+            self._state = result.lower() in ("true", STATE_ON)
+            return
+
+        self._state = False
 
     async def async_added_to_hass(self) -> None:
         """Register callbacks."""
-        self.add_template_attribute("_state", self._template, None, self._update_state)
+        if self._template:
+            self.add_template_attribute(
+                "_state", self._template, None, self._update_state
+            )
+
         if self._preset_mode_template is not None:
             self.add_template_attribute(
                 "_preset_mode",
@@ -396,19 +398,17 @@ class TemplateFan(TemplateEntity, FanEntity):
         # Validate percentage
         try:
             percentage = int(float(percentage))
-        except ValueError:
+        except (ValueError, TypeError):
             _LOGGER.error(
                 "Received invalid percentage: %s for entity %s",
                 percentage,
                 self.entity_id,
             )
             self._percentage = 0
-            self._preset_mode = None
             return
 
         if 0 <= percentage <= 100:
             self._percentage = percentage
-            self._preset_mode = None
         else:
             _LOGGER.error(
                 "Received invalid percentage: %s for entity %s",
@@ -416,7 +416,6 @@ class TemplateFan(TemplateEntity, FanEntity):
                 self.entity_id,
             )
             self._percentage = 0
-            self._preset_mode = None
 
     @callback
     def _update_preset_mode(self, preset_mode):
@@ -424,10 +423,8 @@ class TemplateFan(TemplateEntity, FanEntity):
         preset_mode = str(preset_mode)
 
         if self.preset_modes and preset_mode in self.preset_modes:
-            self._percentage = None
             self._preset_mode = preset_mode
         elif preset_mode in (STATE_UNAVAILABLE, STATE_UNKNOWN):
-            self._percentage = None
             self._preset_mode = None
         else:
             _LOGGER.error(
@@ -436,7 +433,6 @@ class TemplateFan(TemplateEntity, FanEntity):
                 self.entity_id,
                 self.preset_mode,
             )
-            self._percentage = None
             self._preset_mode = None
 
     @callback
@@ -471,3 +467,8 @@ class TemplateFan(TemplateEntity, FanEntity):
                 ", ".join(_VALID_DIRECTIONS),
             )
             self._direction = None
+
+    @property
+    def assumed_state(self) -> bool:
+        """State is assumed, if no template given."""
+        return self._template is None
