@@ -5,7 +5,9 @@ import functools
 import numbers
 from typing import TYPE_CHECKING, Any, TypeVar
 
-from homeassistant.components.climate.const import HVACAction
+from zigpy import types
+
+from homeassistant.components.climate import HVACAction
 from homeassistant.components.sensor import (
     SensorDeviceClass,
     SensorEntity,
@@ -36,6 +38,7 @@ from homeassistant.const import (
     VOLUME_GALLONS,
     VOLUME_LITERS,
     Platform,
+    UnitOfMass,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -183,7 +186,7 @@ class Sensor(ZhaEntity, SensorEntity):
         """Handle state update from channel."""
         self.async_write_ha_state()
 
-    def formatter(self, value: int) -> int | float:
+    def formatter(self, value: int) -> int | float | None:
         """Numeric pass-through formatter."""
         if self._decimals > 0:
             return round(
@@ -216,8 +219,9 @@ class Battery(Sensor):
     SENSOR_ATTR = "battery_percentage_remaining"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.BATTERY
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
-    _unit = PERCENTAGE
     _attr_entity_category = EntityCategory.DIAGNOSTIC
+    _attr_name: str = "Battery"
+    _unit = PERCENTAGE
 
     @classmethod
     def create_entity(
@@ -236,11 +240,11 @@ class Battery(Sensor):
         return cls(unique_id, zha_device, channels, **kwargs)
 
     @staticmethod
-    def formatter(value: int) -> int:  # pylint: disable=arguments-differ
+    def formatter(value: int) -> int | None:  # pylint: disable=arguments-differ
         """Return the state of the entity."""
         # per zcl specs battery percent is reported at 200% ¯\_(ツ)_/¯
         if not isinstance(value, numbers.Number) or value == -1:
-            return value
+            return None
         value = round(value / 2)
         return value
 
@@ -266,15 +270,12 @@ class ElectricalMeasurement(Sensor):
 
     SENSOR_ATTR = "active_power"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.POWER
+    _attr_should_poll = True  # BaseZhaEntity defaults to False
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Active power"
     _unit = POWER_WATT
     _div_mul_prefix = "ac_power"
 
-    @property
-    def should_poll(self) -> bool:
-        """Return True if HA needs to poll for state changes."""
-        return True
-
     @property
     def extra_state_attributes(self) -> dict[str, Any]:
         """Return device state attrs for sensor."""
@@ -312,14 +313,11 @@ class ElectricalMeasurementApparentPower(
 
     SENSOR_ATTR = "apparent_power"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.APPARENT_POWER
+    _attr_should_poll = False  # Poll indirectly by ElectricalMeasurementSensor
+    _attr_name: str = "Apparent power"
     _unit = POWER_VOLT_AMPERE
     _div_mul_prefix = "ac_power"
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll indirectly by ElectricalMeasurementSensor."""
-        return False
-
 
 @MULTI_MATCH(channel_names=CHANNEL_ELECTRICAL_MEASUREMENT)
 class ElectricalMeasurementRMSCurrent(ElectricalMeasurement, id_suffix="rms_current"):
@@ -327,14 +325,11 @@ class ElectricalMeasurementRMSCurrent(ElectricalMeasurement, id_suffix="rms_curr
 
     SENSOR_ATTR = "rms_current"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.CURRENT
+    _attr_should_poll = False  # Poll indirectly by ElectricalMeasurementSensor
+    _attr_name: str = "RMS current"
     _unit = ELECTRIC_CURRENT_AMPERE
     _div_mul_prefix = "ac_current"
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll indirectly by ElectricalMeasurementSensor."""
-        return False
-
 
 @MULTI_MATCH(channel_names=CHANNEL_ELECTRICAL_MEASUREMENT)
 class ElectricalMeasurementRMSVoltage(ElectricalMeasurement, id_suffix="rms_voltage"):
@@ -342,14 +337,11 @@ class ElectricalMeasurementRMSVoltage(ElectricalMeasurement, id_suffix="rms_volt
 
     SENSOR_ATTR = "rms_voltage"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.CURRENT
+    _attr_should_poll = False  # Poll indirectly by ElectricalMeasurementSensor
+    _attr_name: str = "RMS voltage"
     _unit = ELECTRIC_POTENTIAL_VOLT
     _div_mul_prefix = "ac_voltage"
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll indirectly by ElectricalMeasurementSensor."""
-        return False
-
 
 @MULTI_MATCH(channel_names=CHANNEL_ELECTRICAL_MEASUREMENT)
 class ElectricalMeasurementFrequency(ElectricalMeasurement, id_suffix="ac_frequency"):
@@ -357,14 +349,11 @@ class ElectricalMeasurementFrequency(ElectricalMeasurement, id_suffix="ac_freque
 
     SENSOR_ATTR = "ac_frequency"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.FREQUENCY
+    _attr_should_poll = False  # Poll indirectly by ElectricalMeasurementSensor
+    _attr_name: str = "AC frequency"
     _unit = FREQUENCY_HERTZ
     _div_mul_prefix = "ac_frequency"
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll indirectly by ElectricalMeasurementSensor."""
-        return False
-
 
 @MULTI_MATCH(channel_names=CHANNEL_ELECTRICAL_MEASUREMENT)
 class ElectricalMeasurementPowerFactor(ElectricalMeasurement, id_suffix="power_factor"):
@@ -372,13 +361,10 @@ class ElectricalMeasurementPowerFactor(ElectricalMeasurement, id_suffix="power_f
 
     SENSOR_ATTR = "power_factor"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.POWER_FACTOR
+    _attr_should_poll = False  # Poll indirectly by ElectricalMeasurementSensor
+    _attr_name: str = "Power factor"
     _unit = PERCENTAGE
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll indirectly by ElectricalMeasurementSensor."""
-        return False
-
 
 @MULTI_MATCH(
     generic_ids=CHANNEL_ST_HUMIDITY_CLUSTER, stop_on_match_group=CHANNEL_HUMIDITY
@@ -390,6 +376,7 @@ class Humidity(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.HUMIDITY
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Humidity"
     _divisor = 100
     _unit = PERCENTAGE
 
@@ -401,6 +388,7 @@ class SoilMoisture(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.HUMIDITY
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Soil moisture"
     _divisor = 100
     _unit = PERCENTAGE
 
@@ -412,6 +400,7 @@ class LeafWetness(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.HUMIDITY
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Leaf wetness"
     _divisor = 100
     _unit = PERCENTAGE
 
@@ -423,6 +412,7 @@ class Illuminance(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.ILLUMINANCE
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Illuminance"
     _unit = LIGHT_LUX
 
     def formatter(self, value: int) -> float:
@@ -440,6 +430,7 @@ class SmartEnergyMetering(Sensor):
     SENSOR_ATTR: int | str = "instantaneous_demand"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.POWER
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Instantaneous demand"
 
     unit_of_measure_map = {
         0x00: POWER_WATT,
@@ -487,6 +478,7 @@ class SmartEnergySummation(SmartEnergyMetering, id_suffix="summation_delivered")
     SENSOR_ATTR: int | str = "current_summ_delivered"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.ENERGY
     _attr_state_class: SensorStateClass = SensorStateClass.TOTAL_INCREASING
+    _attr_name: str = "Summation delivered"
 
     unit_of_measure_map = {
         0x00: ENERGY_KILO_WATT_HOUR,
@@ -521,10 +513,7 @@ class SmartEnergySummation(SmartEnergyMetering, id_suffix="summation_delivered")
 class PolledSmartEnergySummation(SmartEnergySummation):
     """Polled Smart Energy Metering summation sensor."""
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll the entity for current state."""
-        return True
+    _attr_should_poll = True  # BaseZhaEntity defaults to False
 
     async def async_update(self) -> None:
         """Retrieve latest state."""
@@ -540,6 +529,7 @@ class Pressure(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.PRESSURE
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Pressure"
     _decimals = 0
     _unit = PRESSURE_HPA
 
@@ -551,6 +541,7 @@ class Temperature(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.TEMPERATURE
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Temperature"
     _divisor = 100
     _unit = TEMP_CELSIUS
 
@@ -562,6 +553,7 @@ class DeviceTemperature(Sensor):
     SENSOR_ATTR = "current_temperature"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.TEMPERATURE
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Device temperature"
     _divisor = 100
     _unit = TEMP_CELSIUS
     _attr_entity_category = EntityCategory.DIAGNOSTIC
@@ -574,6 +566,7 @@ class CarbonDioxideConcentration(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.CO2
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Carbon dioxide concentration"
     _decimals = 0
     _multiplier = 1e6
     _unit = CONCENTRATION_PARTS_PER_MILLION
@@ -586,6 +579,7 @@ class CarbonMonoxideConcentration(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.CO
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Carbon monoxide concentration"
     _decimals = 0
     _multiplier = 1e6
     _unit = CONCENTRATION_PARTS_PER_MILLION
@@ -599,6 +593,7 @@ class VOCLevel(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.VOLATILE_ORGANIC_COMPOUNDS
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "VOC level"
     _decimals = 0
     _multiplier = 1e6
     _unit = CONCENTRATION_MICROGRAMS_PER_CUBIC_METER
@@ -615,6 +610,7 @@ class PPBVOCLevel(Sensor):
     SENSOR_ATTR = "measured_value"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.VOLATILE_ORGANIC_COMPOUNDS
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "VOC level"
     _decimals = 0
     _multiplier = 1
     _unit = CONCENTRATION_PARTS_PER_BILLION
@@ -626,6 +622,7 @@ class PM25(Sensor):
 
     SENSOR_ATTR = "measured_value"
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Particulate matter"
     _decimals = 0
     _multiplier = 1
     _unit = CONCENTRATION_MICROGRAMS_PER_CUBIC_METER
@@ -637,6 +634,7 @@ class FormaldehydeConcentration(Sensor):
 
     SENSOR_ATTR = "measured_value"
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_name: str = "Formaldehyde concentration"
     _decimals = 0
     _multiplier = 1e6
     _unit = CONCENTRATION_PARTS_PER_MILLION
@@ -646,6 +644,8 @@ class FormaldehydeConcentration(Sensor):
 class ThermostatHVACAction(Sensor, id_suffix="hvac_action"):
     """Thermostat HVAC action sensor."""
 
+    _attr_name: str = "HVAC action"
+
     @classmethod
     def create_entity(
         cls: type[_ThermostatHVACActionSelfT],
@@ -770,6 +770,8 @@ class RSSISensor(Sensor, id_suffix="rssi"):
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.SIGNAL_STRENGTH
     _attr_entity_category = EntityCategory.DIAGNOSTIC
     _attr_entity_registry_enabled_default = False
+    _attr_should_poll = True  # BaseZhaEntity defaults to False
+    _attr_name: str = "RSSI"
     unique_id_suffix: str
 
     @classmethod
@@ -794,16 +796,13 @@ class RSSISensor(Sensor, id_suffix="rssi"):
         """Return the state of the entity."""
         return getattr(self._zha_device.device, self.unique_id_suffix)
 
-    @property
-    def should_poll(self) -> bool:
-        """Poll the entity for current state."""
-        return True
-
 
 @MULTI_MATCH(channel_names=CHANNEL_BASIC)
 class LQISensor(RSSISensor, id_suffix="lqi"):
     """LQI sensor for a device."""
 
+    _attr_name: str = "LQI"
+
 
 @MULTI_MATCH(
     channel_names="tuya_manufacturer",
@@ -817,6 +816,7 @@ class TimeLeft(Sensor, id_suffix="time_left"):
     SENSOR_ATTR = "timer_time_left"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.DURATION
     _attr_icon = "mdi:timer"
+    _attr_name: str = "Time left"
     _unit = TIME_MINUTES
 
 
@@ -827,6 +827,7 @@ class IkeaDeviceRunTime(Sensor, id_suffix="device_run_time"):
     SENSOR_ATTR = "device_run_time"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.DURATION
     _attr_icon = "mdi:timer"
+    _attr_name: str = "Device run time"
     _unit = TIME_MINUTES
 
 
@@ -837,4 +838,55 @@ class IkeaFilterRunTime(Sensor, id_suffix="filter_run_time"):
     SENSOR_ATTR = "filter_run_time"
     _attr_device_class: SensorDeviceClass = SensorDeviceClass.DURATION
     _attr_icon = "mdi:timer"
+    _attr_name: str = "Filter run time"
     _unit = TIME_MINUTES
+
+
+class AqaraFeedingSource(types.enum8):
+    """Aqara pet feeder feeding source."""
+
+    Feeder = 0x01
+    HomeAssistant = 0x02
+
+
+@MULTI_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+class AqaraPetFeederLastFeedingSource(Sensor, id_suffix="last_feeding_source"):
+    """Sensor that displays the last feeding source of pet feeder."""
+
+    SENSOR_ATTR = "last_feeding_source"
+    _attr_name: str = "Last feeding source"
+    _attr_icon = "mdi:devices"
+
+    def formatter(self, value: int) -> int | float | None:
+        """Numeric pass-through formatter."""
+        return AqaraFeedingSource(value).name
+
+
+@MULTI_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+class AqaraPetFeederLastFeedingSize(Sensor, id_suffix="last_feeding_size"):
+    """Sensor that displays the last feeding size of the pet feeder."""
+
+    SENSOR_ATTR = "last_feeding_size"
+    _attr_name: str = "Last feeding size"
+    _attr_icon: str = "mdi:counter"
+
+
+@MULTI_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+class AqaraPetFeederPortionsDispensed(Sensor, id_suffix="portions_dispensed"):
+    """Sensor that displays the number of portions dispensed by the pet feeder."""
+
+    SENSOR_ATTR = "portions_dispensed"
+    _attr_name: str = "Portions dispensed today"
+    _attr_state_class: SensorStateClass = SensorStateClass.TOTAL_INCREASING
+    _attr_icon: str = "mdi:counter"
+
+
+@MULTI_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
+class AqaraPetFeederWeightDispensed(Sensor, id_suffix="weight_dispensed"):
+    """Sensor that displays the weight weight dispensed by the pet feeder."""
+
+    SENSOR_ATTR = "weight_dispensed"
+    _attr_name: str = "Weight dispensed today"
+    _unit = UnitOfMass.GRAMS
+    _attr_state_class: SensorStateClass = SensorStateClass.TOTAL_INCREASING
+    _attr_icon: str = "mdi:weight-gram"
